@@ -22,4 +22,12 @@ def get_table_for_release() -> Table:
     tb.add_column('Назначено')
     tb.add_column('Автор')
 
+    return tb
+
+
+def get_table_for_versions(caption='Версии проекта') -> Table:
+    tb = Table(show_header=True, header_style='bold magenta', caption=caption)
+    tb.add_column('№', style='dim')
+    tb.add_column('Дата')
+    tb.add_column('Создано')
     return tb
\ No newline at end of file
